@@ -1,6 +1,6 @@
 #' Show logos of the packages inside SIPDIBGE
 #' @description This function shows the survey logos of the packages inside SIPDIBGE.
-#' @import PNADcIBGE POFIBGE PNSIBGE COVIDIBGE cli purrr rstudioapi png grDevices graphics utils tibble
+#' @import COVIDIBGE PNADcIBGE PNSIBGE POFIBGE cli graphics grDevices png purrr rstudioapi tibble utils
 #' @param survey Name of the household survey for reference package information. If \code{NULL}, shows the logos of all the packages inside this collection, including the SIPD logo.
 #' @return An image with the logos required of the packages inside SIPDIBGE.
 #' @note For more information, visit the survey official website <\url{https://www.ibge.gov.br/}> and consult the other functions of this package, described below.
@@ -8,14 +8,14 @@
 #' @examples
 #' \donttest{
 #' sipd_logo()
+#' # Presenting information about the COVIDIBGE package
+#' sipd_logo(survey="COVID")
 #' # Presenting information about the PNADcIBGE package
 #' sipd_logo(survey="PNADC")
-#' # Presenting information about the POFIBGE package
-#' sipd_logo(survey="POF")
 #' # Presenting information about the PNSIBGE package
 #' sipd_logo(survey="PNS")
-#' # Presenting information about the COVIDIBGE package
-#' sipd_logo(survey="COVID")}
+#' # Presenting information about the POFIBGE package
+#' sipd_logo(survey="POF")}
 #' @export
 
 sipd_logo <- function(survey = NULL) {
@@ -23,14 +23,14 @@ sipd_logo <- function(survey = NULL) {
   if (is.null(survey) | !is.character(survey)) {
     survey <- "SIPD"
   }
-  if (toupper(survey) == "PNADC") {
-    logo <- png::readPNG(paste0(system.file("extdata", package="SIPDIBGE"), "/pnadc_logo.png"))
+  if (toupper(survey) == "COVID") {
+    logo <- png::readPNG(paste0(system.file("extdata", package="SIPDIBGE"), "/covid_logo.png"))
     grDevices::dev.new()
     graphics::plot.new()
     graphics::rasterImage(logo,0,0,1,1)
   }
-  else if (toupper(survey) == "POF") {
-    logo <- png::readPNG(paste0(system.file("extdata", package="SIPDIBGE"), "/pof_logo.png"))
+  else if (toupper(survey) == "PNADC") {
+    logo <- png::readPNG(paste0(system.file("extdata", package="SIPDIBGE"), "/pnadc_logo.png"))
     grDevices::dev.new()
     graphics::plot.new()
     graphics::rasterImage(logo,0,0,1,1)
@@ -41,8 +41,8 @@ sipd_logo <- function(survey = NULL) {
     graphics::plot.new()
     graphics::rasterImage(logo,0,0,1,1)
   }
-  else if (toupper(survey) == "COVID") {
-    logo <- png::readPNG(paste0(system.file("extdata", package="SIPDIBGE"), "/covid_logo.png"))
+  else if (toupper(survey) == "POF") {
+    logo <- png::readPNG(paste0(system.file("extdata", package="SIPDIBGE"), "/pof_logo.png"))
     grDevices::dev.new()
     graphics::plot.new()
     graphics::rasterImage(logo,0,0,1,1)
